//
//  MySQLMasterViewController.m
//  MySQL
//
//  Created by Robert Muller on 3/21/12.
//  Copyright (c) 2012 Boston College. All rights reserved.
//

#import "MySQLMasterViewController.h"
#import <sqlite3.h>


@implementation MySQLMasterViewController

sqlite3 *database;

@synthesize titles = _titles;
@synthesize courseNumbers = _courseNumbers;

// Lazy allocation of both the address and phone number arrays.
//
- (NSMutableArray *) titles {
    if(!_titles) _titles = [[NSMutableArray alloc] init];
    return _titles;
}

- (NSMutableArray *) courseNumbers {
    if(!_courseNumbers) _courseNumbers = [[NSMutableArray alloc] init];
    return _courseNumbers;
}

- (void)awakeFromNib
{
    [super awakeFromNib];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    
    NSString *dbPath = [[NSBundle mainBundle] pathForResource:@"courses" ofType:@"db"];
    
    NSLog(@"Path for database.db = %@", dbPath);

    if (sqlite3_open([dbPath UTF8String], &database) != SQLITE_OK) {
        sqlite3_close(database);
        NSLog(@"Couldn't open the database.");
    }
    else {
        NSLog(@"Opened the database.");
        
        sqlite3_stmt    *statement;
        
        NSString *querySQL = @"SELECT COURSE_NUMBER, TITLE FROM COURSE";
        
        const char *query_stmt = [querySQL UTF8String];
        
        sqlite3_prepare_v2(database, query_stmt, -1, &statement, NULL);
        
        while (sqlite3_step(statement) == SQLITE_ROW)
        {
            NSString *courseNumber = [[NSString alloc] initWithUTF8String:
                                      (const char *) sqlite3_column_text(statement, 0)];
 
            [self.courseNumbers  addObject:courseNumber];
    
            NSString *title = [[NSString alloc] initWithUTF8String:
                                    (const char *) sqlite3_column_text(statement, 1)];
    
            [self.titles addObject:title];
            
            // Code to do something with extracted data here
            NSLog(@"address = %@, phone = %@", courseNumber, title);
        }
        sqlite3_finalize(statement);

        sqlite3_close(database);
    }
}

- (NSInteger)tableView:(UITableView *)tableView
 numberOfRowsInSection:(NSInteger)section {
    return [self.courseNumbers count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    static NSString *cellID = @"CellID";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:cellID];
    if (cell == nil) {
        cell = [[UITableViewCell alloc]
                initWithStyle:UITableViewCellStyleSubtitle// Default
                reuseIdentifier:cellID];
    }
    
//    UIImage *image = [UIImage imageNamed:@"star.png"];
//    cell.imageView.image = image;
    
    NSUInteger row = [indexPath row];
    cell.textLabel.text = [self.courseNumbers objectAtIndex:row];
    cell.detailTextLabel.text = [self.titles objectAtIndex:row];
    
    return cell;
}

#pragma mark -
#pragma mark Table Delegate Methods


- (NSInteger)tableView:(UITableView *)tableView
indentationLevelForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 0;
}

-(NSIndexPath *)tableView:(UITableView *)tableView
 willSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    NSUInteger row = [indexPath row];
    
    if (row == 0)
        return nil;
    
    return indexPath;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {

    NSUInteger row = [indexPath row];
    NSString *rowValue = [self.courseNumbers objectAtIndex:row];
    
    NSString *message = [[NSString alloc] initWithFormat:
                         @"You selected %@", rowValue];
    UIAlertView *alert = [[UIAlertView alloc]
                          initWithTitle:@"Row Selected!"
                          message:message
                          delegate:nil
                          cancelButtonTitle:@"Yes I Did"
                          otherButtonTitles:nil];
    [alert show];
    
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
}


- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 70;
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
}

- (void)viewWillDisappear:(BOOL)animated
{
	[super viewWillDisappear:animated];
}

- (void)viewDidDisappear:(BOOL)animated
{
	[super viewDidDisappear:animated];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
}



/*
// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    return YES;
}
*/

/*
// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete the row from the data source.
        [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationFade];
    } else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view.
    }   
}
*/

/*
// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{
}
*/

/*
// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}
*/

@end
